datatypes

package
v0.0.0-...-a23c0e6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 28, 2015 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Derived from the stack implementation at http://rosettacode.org/wiki/Queue#Go 2013/01/22

From http://rosettacode.org/wiki/Stack#Go 2013/01/22

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Queue

type Queue []interface{}

func (*Queue) Empty

func (k *Queue) Empty() bool

func (*Queue) Pop

func (k *Queue) Pop() (s interface{}, ok bool)

func (*Queue) Push

func (k *Queue) Push(s interface{})

type Stack

type Stack []interface{}

func (*Stack) Empty

func (k *Stack) Empty() bool

func (*Stack) Pop

func (k *Stack) Pop() (s interface{}, ok bool)

func (*Stack) Push

func (k *Stack) Push(s interface{})

Directories

Path Synopsis
Package binarytree implements a binary tree To iterate over a tree (where tree is a *Tree), use the Walk() function or a similar method.
Package binarytree implements a binary tree To iterate over a tree (where tree is a *Tree), use the Walk() function or a similar method.

Jump to